Function get.mig.prediction retrieves results of a prediction and creates an object of class
bayesMig.prediction. Function has.mig.prediction checks an existence of such results.
get.mig.prediction(mcmc = NULL, sim.dir = NULL, mcmc.dir = NULL)has.mig.prediction(mcmc = NULL, sim.dir = NULL)
Function get.mig.prediction returns an object of class bayesMig.prediction.
Function has.mig.prediction returns a logical indicating if a prediction exists.
Object of class bayesMig.mcmc.set used to make the prediction.
If it is NULL, the prediction is loaded from directory given by sim.dir.
Directory where the prediction is stored.
Optional argument to be used only in a special case when the mcmc object
contained in the prediction object was estimated in different directory than in the one
to which it points to (for example due to moving or renaming the original directory).
The argument causes that the mcmc is redirected to the given directory.
It can be set to NA if no loading of the mcmc object is desired.
If mcmc is not NULL, the search directory is set to
mcmc$meta$output.dir. This approach assumes that the prediction was stored in the
same directory as the MCMC simulation, i.e. the output.dir argument of the
mig.predict function was set to NULL. If it is not the case,
the argument mcmc.dir should be used.