The function creates two files containing projection summaries, such as the median, the lower and upper bound of the 80 and 90% probability intervals, respectively, and the constant variant. One file is in a user-friendly format, whereas the other is in a UN-specific format with internal coding of the time and the variants.
mig.write.projection.summary(pred, output.dir)No return value.
Object of class bayesMig.prediction.
Directory where output is written.
write.projection.summary