Learn R Programming

bayesMig (version 0.4-6)

summary.bayesMig.convergence: Summary of Convergence Diagnostics

Description

Summary of an object of class bayesMig.convergence created using the mig.diagnose function. It gives an overview about parameters that did not converge.

Usage

# S3 method for bayesMig.convergence
summary(object, expand = FALSE, ...)

Value

List with items that summarize an object of class bayesMig.convergence.

Arguments

object

Object of class bayesMig.prediction.

expand

By default, the function does not show country-specific parameters for which there was no convergence (only country-independent parameters), if the status is ‘red’. This argument can switch that option on.

...

Not used.