Summary of an object bayesMig.mcmc.set or bayesMig.mcmc,
computed via run.mig.mcmc. It can be obtained either for all locations or
for a specific location, and either for all parameters or for specific parameters.
The function uses the summary.mcmc function of the coda package.
# S3 method for bayesMig.mcmc
summary(
object,
country = NULL,
par.names = NULL,
par.names.cs = NULL,
thin = 1,
burnin = 0,
...
)# S3 method for bayesMig.mcmc.set
summary(
object,
country = NULL,
chain.id = NULL,
par.names = NULL,
par.names.cs = NULL,
meta.only = FALSE,
thin = 1,
burnin = 0,
...
)
Return list with elements:
contains meta information about the object.
contains result of summary.mcmc.
optional; available if country is provided as argument.
Object of class bayesMig.mcmc.set or bayesMig.mcmc.
Location name or code if a location-specific summary is desired. The code can be either numeric or (if locations are countries) ISO-2 or ISO-3 characters. By default, summary for all locations is generated.
Country independent parameters (hyperparameters) to be included in the summary.
The default names are given by mig.parameter.names().
Location-specific parameters to be included in the summary.
The default names are given by mig.parameter.names.cs().
Thinning interval. Only used if larger than the thin argument used in run.mig.mcmc.
Number of iterations to be discarded from the beginning of each chain before computing the summary.
Additional arguments passed to the summary.mcmc function of the coda package.
Identifiers of MCMC chains. By default, all chains are considered.
Logical. If it is TRUE, only meta information of the simulation is included.
# See example in ?run.mig.mcmc
Run the code above in your browser using DataLab