Summary of an object of class bayesMig.convergence created
using the mig.diagnose function. It gives an overview about parameters
that did not converge.
# S3 method for bayesMig.convergence
summary(object, expand = FALSE, ...)List with items that summarize an object of class bayesMig.convergence.
Object of class bayesMig.prediction.
By default, the function does not show country-specific parameters for which there was no convergence (only country-independent parameters), if the status is ‘red’. This argument can switch that option on.
Not used.