Summary of an object of class bayesMig.prediction,
created using the function mig.predict. The summary contains the mean,
standard deviation and several commonly used quantiles of the simulated trajectories.
# S3 method for bayesMig.prediction
summary(object, country = NULL, compact = TRUE, ...)# S3 method for summary.bayesMig.prediction
print(x, digits = 3, ...)
summary returns a list with objects burnin, nr.traj, projection.years,
country.name containing the MCMC burn-in, number of trajectories, projected years
and name of the location, respectively. The projection results are stored in the item
projections which is a matrix with rows being the years and columns being the mean
and various quantiles.
Object of class bayesMig.prediction.
Location name or code if a location-specific summary is desired.
The code can be either numeric or (if locations are countries) ISO-2 or ISO-3 characters.
If it is NULL, only prediction meta info is included.
Logical switching between a smaller and larger number of displayed quantiles.
A list of further arguments.
A result of the summary function.
Minimal number of significant digits.